Dataform

Struct Dataform 

pub struct Dataform { /* private fields */ }
Implements a client for the Dataform API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Dataform::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_repositories()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Dataform is a service to develop, create, document, test, and update curated tables in BigQuery.

Configuration

To configure Dataform use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dataform.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

Dataform holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap Dataform in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Dataform

pub fn builder() -> ClientBuilder

Returns a builder for Dataform.

let client = Dataform::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: Dataform + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn get_team_folder(&self) -> GetTeamFolder

Fetches a single TeamFolder.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_team_folder()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_team_folder(&self) -> CreateTeamFolder

Creates a new TeamFolder in a given project and location.

Example
use google_cloud_dataform_v1::model::TeamFolder;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_team_folder()
        .set_parent(parent)
        .set_team_folder(
            TeamFolder::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_team_folder(&self) -> UpdateTeamFolder

Updates a single TeamFolder.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::TeamFolder;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_team_folder()
        .set_team_folder(
            TeamFolder::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_team_folder(&self) -> DeleteTeamFolder

Deletes a single TeamFolder.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_team_folder()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn delete_team_folder_tree(&self) -> DeleteTeamFolderTree

Deletes a TeamFolder with its contents (Folders, Repositories, Workspaces, ReleaseConfigs, and WorkflowConfigs).

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.delete_team_folder_tree()
        /* set fields */
        .poller().until_done().await?;
    Ok(())
}
pub fn query_team_folder_contents(&self) -> QueryTeamFolderContents

Returns the contents of a given TeamFolder.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_team_folder_contents()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn search_team_folders(&self) -> SearchTeamFolders

Returns all TeamFolders in a given location that the caller has access to and match the provided filter.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.search_team_folders()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_folder(&self) -> GetFolder

Fetches a single Folder.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_folder()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_folder(&self) -> CreateFolder

Creates a new Folder in a given project and location.

Example
use google_cloud_dataform_v1::model::Folder;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_folder()
        .set_parent(parent)
        .set_folder(
            Folder::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_folder(&self) -> UpdateFolder

Updates a single Folder.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::Folder;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_folder()
        .set_folder(
            Folder::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_folder(&self) -> DeleteFolder

Deletes a single Folder.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_folder()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn delete_folder_tree(&self) -> DeleteFolderTree

Deletes a Folder with its contents (Folders, Repositories, Workspaces, ReleaseConfigs, and WorkflowConfigs).

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.delete_folder_tree()
        /* set fields */
        .poller().until_done().await?;
    Ok(())
}
pub fn query_folder_contents(&self) -> QueryFolderContents

Returns the contents of a given Folder.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_folder_contents()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn query_user_root_contents(&self) -> QueryUserRootContents

Returns the contents of a caller’s root folder in a given location. The root folder contains all resources that are created by the user and not contained in any other folder.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_user_root_contents()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn move_folder(&self) -> MoveFolder

Moves a Folder to a new Folder, TeamFolder, or the root location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.move_folder()
        /* set fields */
        .poller().until_done().await?;
    Ok(())
}
pub fn list_repositories(&self) -> ListRepositories

Lists Repositories in a given project and location.

Note: This method can return repositories not shown in the Dataform UI.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_repositories()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_repository(&self) -> GetRepository

Fetches a single Repository.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_repository()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_repository(&self) -> CreateRepository

Creates a new Repository in a given project and location.

Example
use google_cloud_dataform_v1::model::Repository;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_repository()
        .set_parent(parent)
        .set_repository_id("repository_id_value")
        .set_repository(
            Repository::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_repository(&self) -> UpdateRepository

Updates a single Repository.

Note: This method does not fully implement AIP/134. The wildcard entry (*) is treated as a bad request, and when the field_mask is omitted, the request is treated as a full update on all modifiable fields.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::Repository;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_repository()
        .set_repository(
            Repository::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_repository(&self) -> DeleteRepository

Deletes a single Repository.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_repository()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn move_repository(&self) -> MoveRepository

Moves a Repository to a new location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.move_repository()
        /* set fields */
        .poller().until_done().await?;
    Ok(())
}
pub fn commit_repository_changes(&self) -> CommitRepositoryChanges

Applies a Git commit to a Repository. The Repository must not have a value for git_remote_settings.url.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.commit_repository_changes()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn read_repository_file(&self) -> ReadRepositoryFile

Returns the contents of a file (inside a Repository). The Repository must not have a value for git_remote_settings.url.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.read_repository_file()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_repository_directory_contents( &self, ) -> QueryRepositoryDirectoryContents

Returns the contents of a given Repository directory. The Repository must not have a value for git_remote_settings.url.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_repository_directory_contents()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn fetch_repository_history(&self) -> FetchRepositoryHistory

Fetches a Repository’s history of commits. The Repository must not have a value for git_remote_settings.url.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.fetch_repository_history()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn compute_repository_access_token_status( &self, ) -> ComputeRepositoryAccessTokenStatus

Computes a Repository’s Git access token status.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.compute_repository_access_token_status()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn fetch_remote_branches(&self) -> FetchRemoteBranches

Fetches a Repository’s remote branches.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.fetch_remote_branches()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_workspaces(&self) -> ListWorkspaces

Lists Workspaces in a given Repository.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_workspaces()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_workspace(&self) -> GetWorkspace

Fetches a single Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_workspace()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_workspace(&self) -> CreateWorkspace

Creates a new Workspace in a given Repository.

Example
use google_cloud_dataform_v1::model::Workspace;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_workspace()
        .set_parent(parent)
        .set_workspace_id("workspace_id_value")
        .set_workspace(
            Workspace::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_workspace(&self) -> DeleteWorkspace

Deletes a single Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_workspace()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn install_npm_packages(&self) -> InstallNpmPackages

Installs dependency NPM packages (inside a Workspace).

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.install_npm_packages()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn pull_git_commits(&self) -> PullGitCommits

Pulls Git commits from the Repository’s remote into a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.pull_git_commits()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn push_git_commits(&self) -> PushGitCommits

Pushes Git commits from a Workspace to the Repository’s remote.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.push_git_commits()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn fetch_file_git_statuses(&self) -> FetchFileGitStatuses

Fetches Git statuses for the files in a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.fetch_file_git_statuses()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn fetch_git_ahead_behind(&self) -> FetchGitAheadBehind

Fetches Git ahead/behind against a remote branch.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.fetch_git_ahead_behind()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn commit_workspace_changes(&self) -> CommitWorkspaceChanges

Applies a Git commit for uncommitted files in a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.commit_workspace_changes()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn reset_workspace_changes(&self) -> ResetWorkspaceChanges

Performs a Git reset for uncommitted files in a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.reset_workspace_changes()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn fetch_file_diff(&self) -> FetchFileDiff

Fetches Git diff for an uncommitted file in a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.fetch_file_diff()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_directory_contents(&self) -> QueryDirectoryContents

Returns the contents of a given Workspace directory.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_directory_contents()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn search_files(&self) -> SearchFiles

Finds the contents of a given Workspace directory by filter.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.search_files()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn make_directory(&self) -> MakeDirectory

Creates a directory inside a Workspace.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.make_directory()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn remove_directory(&self) -> RemoveDirectory

Deletes a directory (inside a Workspace) and all of its contents.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.remove_directory()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn move_directory(&self) -> MoveDirectory

Moves a directory (inside a Workspace), and all of its contents, to a new location.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.move_directory()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn read_file(&self) -> ReadFile

Returns the contents of a file (inside a Workspace).

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.read_file()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn remove_file(&self) -> RemoveFile

Deletes a file (inside a Workspace).

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.remove_file()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn move_file(&self) -> MoveFile

Moves a file (inside a Workspace) to a new location.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.move_file()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn write_file(&self) -> WriteFile

Writes to a file (inside a Workspace).

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.write_file()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_release_configs(&self) -> ListReleaseConfigs

Lists ReleaseConfigs in a given Repository.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_release_configs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_release_config(&self) -> GetReleaseConfig

Fetches a single ReleaseConfig.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_release_config()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_release_config(&self) -> CreateReleaseConfig

Creates a new ReleaseConfig in a given Repository.

Example
use google_cloud_dataform_v1::model::ReleaseConfig;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_release_config()
        .set_parent(parent)
        .set_release_config(
            ReleaseConfig::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_release_config(&self) -> UpdateReleaseConfig

Updates a single ReleaseConfig.

Note: This method does not fully implement AIP/134. The wildcard entry (*) is treated as a bad request, and when the field_mask is omitted, the request is treated as a full update on all modifiable fields.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::ReleaseConfig;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_release_config()
        .set_release_config(
            ReleaseConfig::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_release_config(&self) -> DeleteReleaseConfig

Deletes a single ReleaseConfig.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_release_config()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn list_compilation_results(&self) -> ListCompilationResults

Lists CompilationResults in a given Repository.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_compilation_results()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_compilation_result(&self) -> GetCompilationResult

Fetches a single CompilationResult.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_compilation_result()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_compilation_result(&self) -> CreateCompilationResult

Creates a new CompilationResult in a given project and location.

Example
use google_cloud_dataform_v1::model::CompilationResult;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_compilation_result()
        .set_parent(parent)
        .set_compilation_result(
            CompilationResult::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_compilation_result_actions(&self) -> QueryCompilationResultActions

Returns CompilationResultActions in a given CompilationResult.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_compilation_result_actions()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_workflow_configs(&self) -> ListWorkflowConfigs

Lists WorkflowConfigs in a given Repository.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_workflow_configs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_workflow_config(&self) -> GetWorkflowConfig

Fetches a single WorkflowConfig.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_workflow_config()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_workflow_config(&self) -> CreateWorkflowConfig

Creates a new WorkflowConfig in a given Repository.

Example
use google_cloud_dataform_v1::model::WorkflowConfig;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_workflow_config()
        .set_parent(parent)
        .set_workflow_config(
            WorkflowConfig::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_workflow_config(&self) -> UpdateWorkflowConfig

Updates a single WorkflowConfig.

Note: This method does not fully implement AIP/134. The wildcard entry (*) is treated as a bad request, and when the field_mask is omitted, the request is treated as a full update on all modifiable fields.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::WorkflowConfig;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_workflow_config()
        .set_workflow_config(
            WorkflowConfig::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_workflow_config(&self) -> DeleteWorkflowConfig

Deletes a single WorkflowConfig.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_workflow_config()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn list_workflow_invocations(&self) -> ListWorkflowInvocations

Lists WorkflowInvocations in a given Repository.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let mut list = client.list_workflow_invocations()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_workflow_invocation(&self) -> GetWorkflowInvocation

Fetches a single WorkflowInvocation.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_workflow_invocation()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_workflow_invocation(&self) -> CreateWorkflowInvocation

Creates a new WorkflowInvocation in a given Repository.

Example
use google_cloud_dataform_v1::model::WorkflowInvocation;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, parent: &str
) -> Result<()> {
    let response = client.create_workflow_invocation()
        .set_parent(parent)
        .set_workflow_invocation(
            WorkflowInvocation::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_workflow_invocation(&self) -> DeleteWorkflowInvocation

Deletes a single WorkflowInvocation.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    client.delete_workflow_invocation()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn cancel_workflow_invocation(&self) -> CancelWorkflowInvocation

Requests cancellation of a running WorkflowInvocation.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.cancel_workflow_invocation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn query_workflow_invocation_actions( &self, ) -> QueryWorkflowInvocationActions

Returns WorkflowInvocationActions in a given WorkflowInvocation.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.query_workflow_invocation_actions()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_config(&self) -> GetConfig

Get default config for a given project and location.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.get_config()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_config(&self) -> UpdateConfig

Update default config for a given project and location.

Note: This method does not fully implement AIP/134. The wildcard entry (*) is treated as a bad request, and when the field_mask is omitted, the request is treated as a full update on all modifiable fields.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataform_v1::model::Config;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform, name: &str
) -> Result<()> {
    let response = client.update_config()
        .set_config(
            Config::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:

  • Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataform_v1::Result;
async fn sample(
   client: &Dataform
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}