#[non_exhaustive]pub struct DataPreparation {
pub dependency_targets: Vec<Target>,
pub disabled: bool,
pub tags: Vec<String>,
pub definition: Option<Definition>,
/* private fields */
}Expand description
Defines a compiled Data Preparation entity
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dependency_targets: Vec<Target>A list of actions that this action depends on.
disabled: boolWhether this action is disabled (i.e. should not be run).
Arbitrary, user-defined tags on this action.
definition: Option<Definition>The definition for the data preparation.
Implementations
Sourceimpl DataPreparation
impl DataPreparation
Sourcepub fn set_dependency_targets<T, V>(self, v: T) -> Self
pub fn set_dependency_targets<T, V>(self, v: T) -> Self
Sets the value of dependency_targets.
Example
use google_cloud_dataform_v1::model::Target;
let x = DataPreparation::new()
.set_dependency_targets([
Target::default()/* use setters */,
Target::default()/* use (different) setters */,
]);Sourcepub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
pub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
Sets the value of definition.
Note that all the setters affecting definition are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::data_preparation::Definition;
let x = DataPreparation::new().set_definition(Some(Definition::ContentsYaml("example".to_string())));Sourcepub fn contents_yaml(&self) -> Option<&String>
pub fn contents_yaml(&self) -> Option<&String>
The value of definition
if it holds a ContentsYaml, None if the field is not set or
holds a different branch.
Sourcepub fn set_contents_yaml<T: Into<String>>(self, v: T) -> Self
pub fn set_contents_yaml<T: Into<String>>(self, v: T) -> Self
Sets the value of definition
to hold a ContentsYaml.
Note that all the setters affecting definition are
mutually exclusive.
Example
let x = DataPreparation::new().set_contents_yaml("example");
assert!(x.contents_yaml().is_some());
assert!(x.contents_sql().is_none());Sourcepub fn contents_sql(&self) -> Option<&Box<SqlDefinition>>
pub fn contents_sql(&self) -> Option<&Box<SqlDefinition>>
The value of definition
if it holds a ContentsSql, None if the field is not set or
holds a different branch.
Sourcepub fn set_contents_sql<T: Into<Box<SqlDefinition>>>(self, v: T) -> Self
pub fn set_contents_sql<T: Into<Box<SqlDefinition>>>(self, v: T) -> Self
Sets the value of definition
to hold a ContentsSql.
Note that all the setters affecting definition are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::data_preparation::SqlDefinition;
let x = DataPreparation::new().set_contents_sql(SqlDefinition::default()/* use setters */);
assert!(x.contents_sql().is_some());
assert!(x.contents_yaml().is_none());Trait Implementations
Sourceimpl Clone for DataPreparation
impl Clone for DataPreparation
Sourcefn clone(&self) -> DataPreparation
fn clone(&self) -> DataPreparation
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more