#[non_exhaustive]pub struct LoadConfig {
pub mode: Option<Mode>,
/* private fields */
}Expand description
Simplified load configuration for actions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: Option<Mode>Load mode
Implementations
Sourceimpl LoadConfig
impl LoadConfig
Sourcepub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
pub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
Sets the value of mode.
Note that all the setters affecting mode are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::SimpleLoadMode;
let x = LoadConfig::new().set_mode(Some(
google_cloud_dataform_v1::model::compilation_result_action::load_config::Mode::Replace(SimpleLoadMode::default().into())));Sourcepub fn replace(&self) -> Option<&Box<SimpleLoadMode>>
pub fn replace(&self) -> Option<&Box<SimpleLoadMode>>
The value of mode
if it holds a Replace, None if the field is not set or
holds a different branch.
Sourcepub fn set_replace<T: Into<Box<SimpleLoadMode>>>(self, v: T) -> Self
pub fn set_replace<T: Into<Box<SimpleLoadMode>>>(self, v: T) -> Self
Sets the value of mode
to hold a Replace.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::SimpleLoadMode;
let x = LoadConfig::new().set_replace(SimpleLoadMode::default()/* use setters */);
assert!(x.replace().is_some());
assert!(x.append().is_none());
assert!(x.maximum().is_none());
assert!(x.unique().is_none());Sourcepub fn append(&self) -> Option<&Box<SimpleLoadMode>>
pub fn append(&self) -> Option<&Box<SimpleLoadMode>>
The value of mode
if it holds a Append, None if the field is not set or
holds a different branch.
Sourcepub fn set_append<T: Into<Box<SimpleLoadMode>>>(self, v: T) -> Self
pub fn set_append<T: Into<Box<SimpleLoadMode>>>(self, v: T) -> Self
Sets the value of mode
to hold a Append.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::SimpleLoadMode;
let x = LoadConfig::new().set_append(SimpleLoadMode::default()/* use setters */);
assert!(x.append().is_some());
assert!(x.replace().is_none());
assert!(x.maximum().is_none());
assert!(x.unique().is_none());Sourcepub fn maximum(&self) -> Option<&Box<IncrementalLoadMode>>
pub fn maximum(&self) -> Option<&Box<IncrementalLoadMode>>
The value of mode
if it holds a Maximum, None if the field is not set or
holds a different branch.
Sourcepub fn set_maximum<T: Into<Box<IncrementalLoadMode>>>(self, v: T) -> Self
pub fn set_maximum<T: Into<Box<IncrementalLoadMode>>>(self, v: T) -> Self
Sets the value of mode
to hold a Maximum.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::IncrementalLoadMode;
let x = LoadConfig::new().set_maximum(IncrementalLoadMode::default()/* use setters */);
assert!(x.maximum().is_some());
assert!(x.replace().is_none());
assert!(x.append().is_none());
assert!(x.unique().is_none());Sourcepub fn unique(&self) -> Option<&Box<IncrementalLoadMode>>
pub fn unique(&self) -> Option<&Box<IncrementalLoadMode>>
The value of mode
if it holds a Unique, None if the field is not set or
holds a different branch.
Sourcepub fn set_unique<T: Into<Box<IncrementalLoadMode>>>(self, v: T) -> Self
pub fn set_unique<T: Into<Box<IncrementalLoadMode>>>(self, v: T) -> Self
Sets the value of mode
to hold a Unique.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::IncrementalLoadMode;
let x = LoadConfig::new().set_unique(IncrementalLoadMode::default()/* use setters */);
assert!(x.unique().is_some());
assert!(x.replace().is_none());
assert!(x.append().is_none());
assert!(x.maximum().is_none());Trait Implementations
Sourceimpl Clone for LoadConfig
impl Clone for LoadConfig
Sourcefn clone(&self) -> LoadConfig
fn clone(&self) -> LoadConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LoadConfig
impl Debug for LoadConfig
Sourceimpl Default for LoadConfig
impl Default for LoadConfig
Sourcefn default() -> LoadConfig
fn default() -> LoadConfig
Sourceimpl PartialEq for LoadConfig
impl PartialEq for LoadConfig
impl StructuralPartialEq for LoadConfig