#[non_exhaustive]pub enum QueryPriority {
Unspecified,
Interactive,
Batch,
UnknownValue(UnknownValue),
}Expand description
Types of priority for query execution in BigQuery.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value. This value is unused.
Interactive
Query will be executed in BigQuery with interactive priority. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#queries.
Batch
Query will be executed in BigQuery with batch priority. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using QueryPriority::value or QueryPriority::name.
Implementations