#[non_exhaustive]pub struct FolderContentsEntry {
pub entry: Option<Entry>,
/* private fields */
}Expand description
Represents a single content entry.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry: Option<Entry>The content entry.
Implementations
Sourceimpl FolderContentsEntry
impl FolderContentsEntry
pub fn new() -> Self
Sourcepub fn set_entry<T: Into<Option<Entry>>>(self, v: T) -> Self
pub fn set_entry<T: Into<Option<Entry>>>(self, v: T) -> Self
Sets the value of entry.
Note that all the setters affecting entry are mutually
exclusive.
Example
ⓘ
use google_cloud_dataform_v1::model::Folder;
let x = FolderContentsEntry::new().set_entry(Some(
google_cloud_dataform_v1::model::query_folder_contents_response::folder_contents_entry::Entry::Folder(Folder::default().into())));Sourcepub fn folder(&self) -> Option<&Box<Folder>>
pub fn folder(&self) -> Option<&Box<Folder>>
The value of entry
if it holds a Folder, None if the field is not set or
holds a different branch.
Sourcepub fn set_folder<T: Into<Box<Folder>>>(self, v: T) -> Self
pub fn set_folder<T: Into<Box<Folder>>>(self, v: T) -> Self
Sets the value of entry
to hold a Folder.
Note that all the setters affecting entry are
mutually exclusive.
Example
ⓘ
use google_cloud_dataform_v1::model::Folder;
let x = FolderContentsEntry::new().set_folder(Folder::default()/* use setters */);
assert!(x.folder().is_some());
assert!(x.repository().is_none());Sourcepub fn repository(&self) -> Option<&Box<Repository>>
pub fn repository(&self) -> Option<&Box<Repository>>
The value of entry
if it holds a Repository, None if the field is not set or
holds a different branch.
Sourcepub fn set_repository<T: Into<Box<Repository>>>(self, v: T) -> Self
pub fn set_repository<T: Into<Box<Repository>>>(self, v: T) -> Self
Sets the value of entry
to hold a Repository.
Note that all the setters affecting entry are
mutually exclusive.
Example
ⓘ
use google_cloud_dataform_v1::model::Repository;
let x = FolderContentsEntry::new().set_repository(Repository::default()/* use setters */);
assert!(x.repository().is_some());
assert!(x.folder().is_none());Trait Implementations
Sourceimpl Clone for FolderContentsEntry
impl Clone for FolderContentsEntry
Sourcefn clone(&self) -> FolderContentsEntry
fn clone(&self) -> FolderContentsEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FolderContentsEntry
impl Debug for FolderContentsEntry
Sourceimpl Default for FolderContentsEntry
impl Default for FolderContentsEntry
Sourcefn default() -> FolderContentsEntry
fn default() -> FolderContentsEntry
Returns the “default value” for a type. Read more
Sourceimpl Message for FolderContentsEntry
impl Message for FolderContentsEntry
Sourceimpl PartialEq for FolderContentsEntry
impl PartialEq for FolderContentsEntry
impl StructuralPartialEq for FolderContentsEntry