#[non_exhaustive]pub struct GitRemoteSettings {
pub url: String,
pub default_branch: String,
pub effective_default_branch: String,
pub authentication_token_secret_version: String,
pub ssh_authentication_config: Option<SshAuthenticationConfig>,
pub git_repository_link: Option<String>,
pub token_status: TokenStatus,
/* private fields */
}Expand description
Controls Git remote configuration for a repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringRequired. The Git remote’s URL.
default_branch: StringOptional. The Git remote’s default branch name.
If not set, main will be used.
effective_default_branch: StringOutput only. The Git remote’s effective default branch name.
This is the default branch name of the Git remote if it is set,
otherwise it is main.
authentication_token_secret_version: StringOptional. The name of the Secret Manager secret version to use as an
authentication token for Git operations. Must be in the format
projects/*/secrets/*/versions/*.
ssh_authentication_config: Option<SshAuthenticationConfig>Optional. Authentication fields for remote uris using SSH protocol.
git_repository_link: Option<String>Optional. Resource name for the GitRepositoryLink used for machine
credentials. Must be in the format
projects/*/locations/*/connections/*/gitRepositoryLinks/*
token_status: TokenStatusOutput only. Deprecated: The field does not contain any token status information.
Implementations
Sourceimpl GitRemoteSettings
impl GitRemoteSettings
Sourcepub fn set_default_branch<T: Into<String>>(self, v: T) -> Self
pub fn set_default_branch<T: Into<String>>(self, v: T) -> Self
Sets the value of default_branch.
Example
let x = GitRemoteSettings::new().set_default_branch("example");Sourcepub fn set_effective_default_branch<T: Into<String>>(self, v: T) -> Self
pub fn set_effective_default_branch<T: Into<String>>(self, v: T) -> Self
Sets the value of effective_default_branch.
Example
let x = GitRemoteSettings::new().set_effective_default_branch("example");Sourcepub fn set_authentication_token_secret_version<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_authentication_token_secret_version<T: Into<String>>( self, v: T, ) -> Self
Sets the value of authentication_token_secret_version.
Example
let x = GitRemoteSettings::new().set_authentication_token_secret_version("example");Sourcepub fn set_ssh_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<SshAuthenticationConfig>,
pub fn set_ssh_authentication_config<T>(self, v: T) -> Selfwhere
T: Into<SshAuthenticationConfig>,
Sets the value of ssh_authentication_config.
Example
use google_cloud_dataform_v1::model::repository::git_remote_settings::SshAuthenticationConfig;
let x = GitRemoteSettings::new().set_ssh_authentication_config(SshAuthenticationConfig::default()/* use setters */);Sourcepub fn set_or_clear_ssh_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SshAuthenticationConfig>,
pub fn set_or_clear_ssh_authentication_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SshAuthenticationConfig>,
Sets or clears the value of ssh_authentication_config.
Example
use google_cloud_dataform_v1::model::repository::git_remote_settings::SshAuthenticationConfig;
let x = GitRemoteSettings::new().set_or_clear_ssh_authentication_config(Some(SshAuthenticationConfig::default()/* use setters */));
let x = GitRemoteSettings::new().set_or_clear_ssh_authentication_config(None::<SshAuthenticationConfig>);Sourcepub fn set_git_repository_link<T>(self, v: T) -> Self
pub fn set_git_repository_link<T>(self, v: T) -> Self
Sets the value of git_repository_link.
Example
let x = GitRemoteSettings::new().set_git_repository_link("example");Sourcepub fn set_or_clear_git_repository_link<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_git_repository_link<T>(self, v: Option<T>) -> Self
Sets or clears the value of git_repository_link.
Example
let x = GitRemoteSettings::new().set_or_clear_git_repository_link(Some("example"));
let x = GitRemoteSettings::new().set_or_clear_git_repository_link(None::<String>);Sourcepub fn set_token_status<T: Into<TokenStatus>>(self, v: T) -> Self
👎Deprecated
pub fn set_token_status<T: Into<TokenStatus>>(self, v: T) -> Self
Sets the value of token_status.
Example
use google_cloud_dataform_v1::model::repository::git_remote_settings::TokenStatus;
let x0 = GitRemoteSettings::new().set_token_status(TokenStatus::NotFound);
let x1 = GitRemoteSettings::new().set_token_status(TokenStatus::Invalid);
let x2 = GitRemoteSettings::new().set_token_status(TokenStatus::Valid);Trait Implementations
Sourceimpl Clone for GitRemoteSettings
impl Clone for GitRemoteSettings
Sourcefn clone(&self) -> GitRemoteSettings
fn clone(&self) -> GitRemoteSettings
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GitRemoteSettings
impl Debug for GitRemoteSettings
Sourceimpl Default for GitRemoteSettings
impl Default for GitRemoteSettings
Sourcefn default() -> GitRemoteSettings
fn default() -> GitRemoteSettings
Sourceimpl Message for GitRemoteSettings
impl Message for GitRemoteSettings
Sourceimpl PartialEq for GitRemoteSettings
impl PartialEq for GitRemoteSettings
impl StructuralPartialEq for GitRemoteSettings