#[non_exhaustive]pub struct CodeCompilationConfig {
pub default_database: String,
pub default_schema: String,
pub default_location: String,
pub assertion_schema: String,
pub vars: HashMap<String, String>,
pub database_suffix: String,
pub schema_suffix: String,
pub table_prefix: String,
pub builtin_assertion_name_prefix: String,
pub default_notebook_runtime_options: Option<NotebookRuntimeOptions>,
/* private fields */
}Expand description
Configures various aspects of Dataform code compilation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default_database: StringOptional. The default database (Google Cloud project ID).
default_schema: StringOptional. The default schema (BigQuery dataset ID).
default_location: StringOptional. The default BigQuery location to use. Defaults to “US”. See the BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/docs/locations.
assertion_schema: StringOptional. The default schema (BigQuery dataset ID) for assertions.
vars: HashMap<String, String>Optional. User-defined variables that are made available to project code during compilation.
database_suffix: StringOptional. The suffix that should be appended to all database (Google Cloud project ID) names.
schema_suffix: StringOptional. The suffix that should be appended to all schema (BigQuery dataset ID) names.
table_prefix: StringOptional. The prefix that should be prepended to all table names.
builtin_assertion_name_prefix: StringOptional. The prefix to prepend to built-in assertion names.
default_notebook_runtime_options: Option<NotebookRuntimeOptions>Optional. The default notebook runtime options.
Implementations
Sourceimpl CodeCompilationConfig
impl CodeCompilationConfig
Sourcepub fn set_default_database<T: Into<String>>(self, v: T) -> Self
pub fn set_default_database<T: Into<String>>(self, v: T) -> Self
Sets the value of default_database.
Example
let x = CodeCompilationConfig::new().set_default_database("example");Sourcepub fn set_default_schema<T: Into<String>>(self, v: T) -> Self
pub fn set_default_schema<T: Into<String>>(self, v: T) -> Self
Sets the value of default_schema.
Example
let x = CodeCompilationConfig::new().set_default_schema("example");Sourcepub fn set_default_location<T: Into<String>>(self, v: T) -> Self
pub fn set_default_location<T: Into<String>>(self, v: T) -> Self
Sets the value of default_location.
Example
let x = CodeCompilationConfig::new().set_default_location("example");Sourcepub fn set_assertion_schema<T: Into<String>>(self, v: T) -> Self
pub fn set_assertion_schema<T: Into<String>>(self, v: T) -> Self
Sets the value of assertion_schema.
Example
let x = CodeCompilationConfig::new().set_assertion_schema("example");Sourcepub fn set_database_suffix<T: Into<String>>(self, v: T) -> Self
pub fn set_database_suffix<T: Into<String>>(self, v: T) -> Self
Sets the value of database_suffix.
Example
let x = CodeCompilationConfig::new().set_database_suffix("example");Sourcepub fn set_schema_suffix<T: Into<String>>(self, v: T) -> Self
pub fn set_schema_suffix<T: Into<String>>(self, v: T) -> Self
Sets the value of schema_suffix.
Example
let x = CodeCompilationConfig::new().set_schema_suffix("example");Sourcepub fn set_table_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_table_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of table_prefix.
Example
let x = CodeCompilationConfig::new().set_table_prefix("example");Sourcepub fn set_builtin_assertion_name_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_builtin_assertion_name_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of builtin_assertion_name_prefix.
Example
let x = CodeCompilationConfig::new().set_builtin_assertion_name_prefix("example");Sourcepub fn set_default_notebook_runtime_options<T>(self, v: T) -> Selfwhere
T: Into<NotebookRuntimeOptions>,
pub fn set_default_notebook_runtime_options<T>(self, v: T) -> Selfwhere
T: Into<NotebookRuntimeOptions>,
Sets the value of default_notebook_runtime_options.
Example
use google_cloud_dataform_v1::model::NotebookRuntimeOptions;
let x = CodeCompilationConfig::new().set_default_notebook_runtime_options(NotebookRuntimeOptions::default()/* use setters */);Sourcepub fn set_or_clear_default_notebook_runtime_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<NotebookRuntimeOptions>,
pub fn set_or_clear_default_notebook_runtime_options<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<NotebookRuntimeOptions>,
Sets or clears the value of default_notebook_runtime_options.
Example
use google_cloud_dataform_v1::model::NotebookRuntimeOptions;
let x = CodeCompilationConfig::new().set_or_clear_default_notebook_runtime_options(Some(NotebookRuntimeOptions::default()/* use setters */));
let x = CodeCompilationConfig::new().set_or_clear_default_notebook_runtime_options(None::<NotebookRuntimeOptions>);Trait Implementations
Sourceimpl Clone for CodeCompilationConfig
impl Clone for CodeCompilationConfig
Sourcefn clone(&self) -> CodeCompilationConfig
fn clone(&self) -> CodeCompilationConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CodeCompilationConfig
impl Debug for CodeCompilationConfig
Sourceimpl Default for CodeCompilationConfig
impl Default for CodeCompilationConfig
Sourcefn default() -> CodeCompilationConfig
fn default() -> CodeCompilationConfig
Sourceimpl Message for CodeCompilationConfig
impl Message for CodeCompilationConfig
Sourceimpl PartialEq for CodeCompilationConfig
impl PartialEq for CodeCompilationConfig
impl StructuralPartialEq for CodeCompilationConfig