#[non_exhaustive]pub struct CompilationResult {
pub name: String,
pub code_compilation_config: Option<CodeCompilationConfig>,
pub resolved_git_commit_sha: String,
pub dataform_core_version: String,
pub compilation_errors: Vec<CompilationError>,
pub data_encryption_state: Option<DataEncryptionState>,
pub create_time: Option<Timestamp>,
pub internal_metadata: Option<String>,
pub private_resource_metadata: Option<PrivateResourceMetadata>,
pub source: Option<Source>,
/* private fields */
}Expand description
Represents the result of compiling a Dataform project.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The compilation result’s name.
code_compilation_config: Option<CodeCompilationConfig>Immutable. If set, fields of code_compilation_config override the default
compilation settings that are specified in dataform.json.
resolved_git_commit_sha: StringOutput only. The fully resolved Git commit SHA of the code that was compiled. Not set for compilation results whose source is a workspace.
dataform_core_version: StringOutput only. The version of @dataform/core that was used for compilation.
compilation_errors: Vec<CompilationError>Output only. Errors encountered during project compilation.
data_encryption_state: Option<DataEncryptionState>Output only. Only set if the repository has a KMS Key.
create_time: Option<Timestamp>Output only. The timestamp of when the compilation result was created.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
private_resource_metadata: Option<PrivateResourceMetadata>Output only. Metadata indicating whether this resource is user-scoped.
CompilationResult resource is user_scoped only if it is sourced
from a workspace.
source: Option<Source>The source of the compilation result.
Implementations
Sourceimpl CompilationResult
impl CompilationResult
Sourcepub fn set_code_compilation_config<T>(self, v: T) -> Selfwhere
T: Into<CodeCompilationConfig>,
pub fn set_code_compilation_config<T>(self, v: T) -> Selfwhere
T: Into<CodeCompilationConfig>,
Sets the value of code_compilation_config.
Example
use google_cloud_dataform_v1::model::CodeCompilationConfig;
let x = CompilationResult::new().set_code_compilation_config(CodeCompilationConfig::default()/* use setters */);Sourcepub fn set_or_clear_code_compilation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CodeCompilationConfig>,
pub fn set_or_clear_code_compilation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<CodeCompilationConfig>,
Sets or clears the value of code_compilation_config.
Example
use google_cloud_dataform_v1::model::CodeCompilationConfig;
let x = CompilationResult::new().set_or_clear_code_compilation_config(Some(CodeCompilationConfig::default()/* use setters */));
let x = CompilationResult::new().set_or_clear_code_compilation_config(None::<CodeCompilationConfig>);Sourcepub fn set_resolved_git_commit_sha<T: Into<String>>(self, v: T) -> Self
pub fn set_resolved_git_commit_sha<T: Into<String>>(self, v: T) -> Self
Sets the value of resolved_git_commit_sha.
Example
let x = CompilationResult::new().set_resolved_git_commit_sha("example");Sourcepub fn set_dataform_core_version<T: Into<String>>(self, v: T) -> Self
pub fn set_dataform_core_version<T: Into<String>>(self, v: T) -> Self
Sets the value of dataform_core_version.
Example
let x = CompilationResult::new().set_dataform_core_version("example");Sourcepub fn set_compilation_errors<T, V>(self, v: T) -> Self
pub fn set_compilation_errors<T, V>(self, v: T) -> Self
Sets the value of compilation_errors.
Example
use google_cloud_dataform_v1::model::compilation_result::CompilationError;
let x = CompilationResult::new()
.set_compilation_errors([
CompilationError::default()/* use setters */,
CompilationError::default()/* use (different) setters */,
]);Sourcepub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
Sets the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = CompilationResult::new().set_data_encryption_state(DataEncryptionState::default()/* use setters */);Sourcepub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
Sets or clears the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = CompilationResult::new().set_or_clear_data_encryption_state(Some(DataEncryptionState::default()/* use setters */));
let x = CompilationResult::new().set_or_clear_data_encryption_state(None::<DataEncryptionState>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = CompilationResult::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = CompilationResult::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = CompilationResult::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = CompilationResult::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = CompilationResult::new().set_or_clear_internal_metadata(Some("example"));
let x = CompilationResult::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = CompilationResult::new().set_private_resource_metadata(PrivateResourceMetadata::default()/* use setters */);Sourcepub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets or clears the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = CompilationResult::new().set_or_clear_private_resource_metadata(Some(PrivateResourceMetadata::default()/* use setters */));
let x = CompilationResult::new().set_or_clear_private_resource_metadata(None::<PrivateResourceMetadata>);Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sourcepub fn git_commitish(&self) -> Option<&String>
pub fn git_commitish(&self) -> Option<&String>
The value of source
if it holds a GitCommitish, None if the field is not set or
holds a different branch.
Sourcepub fn set_git_commitish<T: Into<String>>(self, v: T) -> Self
pub fn set_git_commitish<T: Into<String>>(self, v: T) -> Self
Sourcepub fn workspace(&self) -> Option<&String>
pub fn workspace(&self) -> Option<&String>
The value of source
if it holds a Workspace, None if the field is not set or
holds a different branch.
Sourcepub fn set_workspace<T: Into<String>>(self, v: T) -> Self
pub fn set_workspace<T: Into<String>>(self, v: T) -> Self
Sets the value of source
to hold a Workspace.
Note that all the setters affecting source are
mutually exclusive.
Example
let x = CompilationResult::new().set_workspace(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/workspaces/{workspace_id}"));
assert!(x.workspace().is_some());
assert!(x.git_commitish().is_none());
assert!(x.release_config().is_none());Sourcepub fn release_config(&self) -> Option<&String>
pub fn release_config(&self) -> Option<&String>
The value of source
if it holds a ReleaseConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_release_config<T: Into<String>>(self, v: T) -> Self
pub fn set_release_config<T: Into<String>>(self, v: T) -> Self
Sets the value of source
to hold a ReleaseConfig.
Note that all the setters affecting source are
mutually exclusive.
Example
let x = CompilationResult::new().set_release_config(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/releaseConfigs/{release_config_id}"));
assert!(x.release_config().is_some());
assert!(x.git_commitish().is_none());
assert!(x.workspace().is_none());Trait Implementations
Sourceimpl Clone for CompilationResult
impl Clone for CompilationResult
Sourcefn clone(&self) -> CompilationResult
fn clone(&self) -> CompilationResult
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CompilationResult
impl Debug for CompilationResult
Sourceimpl Default for CompilationResult
impl Default for CompilationResult
Sourcefn default() -> CompilationResult
fn default() -> CompilationResult
Sourceimpl Message for CompilationResult
impl Message for CompilationResult
Sourceimpl PartialEq for CompilationResult
impl PartialEq for CompilationResult
impl StructuralPartialEq for CompilationResult