#[non_exhaustive]pub struct CompilationResultAction {
pub target: Option<Target>,
pub canonical_target: Option<Target>,
pub file_path: String,
pub internal_metadata: Option<String>,
pub compiled_object: Option<CompiledObject>,
/* private fields */
}Expand description
Represents a single Dataform action in a compilation result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target: Option<Target>This action’s identifier. Unique within the compilation result.
canonical_target: Option<Target>The action’s identifier if the project had been compiled without any overrides configured. Unique within the compilation result.
file_path: StringThe full path including filename in which this action is located, relative to the workspace root.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
compiled_object: Option<CompiledObject>The compiled object.
Implementations
Sourceimpl CompilationResultAction
impl CompilationResultAction
Sourcepub fn set_target<T>(self, v: T) -> Self
pub fn set_target<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_target<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_target<T>(self, v: Option<T>) -> Self
Sourcepub fn set_canonical_target<T>(self, v: T) -> Self
pub fn set_canonical_target<T>(self, v: T) -> Self
Sets the value of canonical_target.
Example
use google_cloud_dataform_v1::model::Target;
let x = CompilationResultAction::new().set_canonical_target(Target::default()/* use setters */);Sourcepub fn set_or_clear_canonical_target<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_canonical_target<T>(self, v: Option<T>) -> Self
Sets or clears the value of canonical_target.
Example
use google_cloud_dataform_v1::model::Target;
let x = CompilationResultAction::new().set_or_clear_canonical_target(Some(Target::default()/* use setters */));
let x = CompilationResultAction::new().set_or_clear_canonical_target(None::<Target>);Sourcepub fn set_file_path<T: Into<String>>(self, v: T) -> Self
pub fn set_file_path<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = CompilationResultAction::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = CompilationResultAction::new().set_or_clear_internal_metadata(Some("example"));
let x = CompilationResultAction::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_compiled_object<T: Into<Option<CompiledObject>>>(self, v: T) -> Self
pub fn set_compiled_object<T: Into<Option<CompiledObject>>>(self, v: T) -> Self
Sets the value of compiled_object.
Note that all the setters affecting compiled_object are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Relation;
let x = CompilationResultAction::new().set_compiled_object(Some(
google_cloud_dataform_v1::model::compilation_result_action::CompiledObject::Relation(Relation::default().into())));Sourcepub fn relation(&self) -> Option<&Box<Relation>>
pub fn relation(&self) -> Option<&Box<Relation>>
The value of compiled_object
if it holds a Relation, None if the field is not set or
holds a different branch.
Sourcepub fn set_relation<T: Into<Box<Relation>>>(self, v: T) -> Self
pub fn set_relation<T: Into<Box<Relation>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a Relation.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Relation;
let x = CompilationResultAction::new().set_relation(Relation::default()/* use setters */);
assert!(x.relation().is_some());
assert!(x.operations().is_none());
assert!(x.assertion().is_none());
assert!(x.declaration().is_none());
assert!(x.notebook().is_none());
assert!(x.data_preparation().is_none());Sourcepub fn operations(&self) -> Option<&Box<Operations>>
pub fn operations(&self) -> Option<&Box<Operations>>
The value of compiled_object
if it holds a Operations, None if the field is not set or
holds a different branch.
Sourcepub fn set_operations<T: Into<Box<Operations>>>(self, v: T) -> Self
pub fn set_operations<T: Into<Box<Operations>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a Operations.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Operations;
let x = CompilationResultAction::new().set_operations(Operations::default()/* use setters */);
assert!(x.operations().is_some());
assert!(x.relation().is_none());
assert!(x.assertion().is_none());
assert!(x.declaration().is_none());
assert!(x.notebook().is_none());
assert!(x.data_preparation().is_none());Sourcepub fn assertion(&self) -> Option<&Box<Assertion>>
pub fn assertion(&self) -> Option<&Box<Assertion>>
The value of compiled_object
if it holds a Assertion, None if the field is not set or
holds a different branch.
Sourcepub fn set_assertion<T: Into<Box<Assertion>>>(self, v: T) -> Self
pub fn set_assertion<T: Into<Box<Assertion>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a Assertion.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Assertion;
let x = CompilationResultAction::new().set_assertion(Assertion::default()/* use setters */);
assert!(x.assertion().is_some());
assert!(x.relation().is_none());
assert!(x.operations().is_none());
assert!(x.declaration().is_none());
assert!(x.notebook().is_none());
assert!(x.data_preparation().is_none());Sourcepub fn declaration(&self) -> Option<&Box<Declaration>>
pub fn declaration(&self) -> Option<&Box<Declaration>>
The value of compiled_object
if it holds a Declaration, None if the field is not set or
holds a different branch.
Sourcepub fn set_declaration<T: Into<Box<Declaration>>>(self, v: T) -> Self
pub fn set_declaration<T: Into<Box<Declaration>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a Declaration.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Declaration;
let x = CompilationResultAction::new().set_declaration(Declaration::default()/* use setters */);
assert!(x.declaration().is_some());
assert!(x.relation().is_none());
assert!(x.operations().is_none());
assert!(x.assertion().is_none());
assert!(x.notebook().is_none());
assert!(x.data_preparation().is_none());Sourcepub fn notebook(&self) -> Option<&Box<Notebook>>
pub fn notebook(&self) -> Option<&Box<Notebook>>
The value of compiled_object
if it holds a Notebook, None if the field is not set or
holds a different branch.
Sourcepub fn set_notebook<T: Into<Box<Notebook>>>(self, v: T) -> Self
pub fn set_notebook<T: Into<Box<Notebook>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a Notebook.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::Notebook;
let x = CompilationResultAction::new().set_notebook(Notebook::default()/* use setters */);
assert!(x.notebook().is_some());
assert!(x.relation().is_none());
assert!(x.operations().is_none());
assert!(x.assertion().is_none());
assert!(x.declaration().is_none());
assert!(x.data_preparation().is_none());Sourcepub fn data_preparation(&self) -> Option<&Box<DataPreparation>>
pub fn data_preparation(&self) -> Option<&Box<DataPreparation>>
The value of compiled_object
if it holds a DataPreparation, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_preparation<T: Into<Box<DataPreparation>>>(self, v: T) -> Self
pub fn set_data_preparation<T: Into<Box<DataPreparation>>>(self, v: T) -> Self
Sets the value of compiled_object
to hold a DataPreparation.
Note that all the setters affecting compiled_object are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::compilation_result_action::DataPreparation;
let x = CompilationResultAction::new().set_data_preparation(DataPreparation::default()/* use setters */);
assert!(x.data_preparation().is_some());
assert!(x.relation().is_none());
assert!(x.operations().is_none());
assert!(x.assertion().is_none());
assert!(x.declaration().is_none());
assert!(x.notebook().is_none());Trait Implementations
Sourceimpl Clone for CompilationResultAction
impl Clone for CompilationResultAction
Sourcefn clone(&self) -> CompilationResultAction
fn clone(&self) -> CompilationResultAction
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CompilationResultAction
impl Debug for CompilationResultAction
Sourceimpl Default for CompilationResultAction
impl Default for CompilationResultAction
Sourcefn default() -> CompilationResultAction
fn default() -> CompilationResultAction
Sourceimpl Message for CompilationResultAction
impl Message for CompilationResultAction
Sourceimpl PartialEq for CompilationResultAction
impl PartialEq for CompilationResultAction
impl StructuralPartialEq for CompilationResultAction