#[non_exhaustive]pub struct Config {
pub name: String,
pub default_kms_key_name: String,
pub internal_metadata: Option<String>,
/* private fields */
}Expand description
Config for all repositories in a given project and location.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The config name.
default_kms_key_name: StringOptional. The default KMS key that is used if no encryption key is provided when a repository is created.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
Implementations
Sourceimpl Config
impl Config
pub fn new() -> Self
Sourcepub fn set_default_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_default_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of default_kms_key_name.
Example
ⓘ
let x = Config::new().set_default_kms_key_name("example");Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
ⓘ
let x = Config::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
ⓘ
let x = Config::new().set_or_clear_internal_metadata(Some("example"));
let x = Config::new().set_or_clear_internal_metadata(None::<String>);Trait Implementations
impl StructuralPartialEq for Config