#[non_exhaustive]pub struct DeleteFolderTreeRequest {
pub name: String,
pub force: bool,
/* private fields */
}Expand description
DeleteFolderTree request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The Folder’s name. Format: projects/{project}/locations/{location}/folders/{folder}
force: boolOptional. If false (default): The operation will fail if any
Repository within the folder hierarchy has associated Release Configs or
Workflow Configs.
If true: The operation will attempt to delete everything, including any
Release Configs and Workflow Configs linked to Repositories within the
folder hierarchy. This permanently removes schedules and resources.
Implementations