DeleteTeamFolderTreeRequest

Struct DeleteTeamFolderTreeRequest 

#[non_exhaustive]
pub struct DeleteTeamFolderTreeRequest { pub name: String, pub force: bool, /* private fields */ }
DeleteTeamFolderTree request message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The TeamFolder’s name. Format: projects/{project}/locations/{location}/teamFolders/{team_folder}

force: bool

Optional. If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs.

If true: The operation will attempt to delete everything, including any Release Configs and Workflow Configs linked to Repositories within the folder hierarchy. This permanently removes schedules and resources.

Implementations

Source

impl DeleteTeamFolderTreeRequest

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DeleteTeamFolderTreeRequest::new().set_name("example");
pub fn set_force<T: Into<bool>>(self, v: T) -> Self

Sets the value of force.

Example
let x = DeleteTeamFolderTreeRequest::new().set_force(true);