#[non_exhaustive]pub struct Folder {
pub name: String,
pub display_name: String,
pub containing_folder: String,
pub team_folder_name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub internal_metadata: Option<String>,
pub creator_iam_principal: Option<String>,
/* private fields */
}Expand description
Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The Folder’s name.
display_name: StringRequired. The Folder’s user-friendly name.
containing_folder: StringOptional. The containing Folder resource name. This should take the format: projects/{project}/locations/{location}/folders/{folder}, projects/{project}/locations/{location}/teamFolders/{teamFolder}, or just projects/{project}/locations/{location} if this is a root Folder. This field can only be updated through MoveFolder.
team_folder_name: StringOutput only. The resource name of the TeamFolder that this Folder is associated with. This should take the format: projects/{project}/locations/{location}/teamFolders/{teamFolder}. If this is not set, the Folder is not associated with a TeamFolder and is a UserFolder.
create_time: Option<Timestamp>Output only. The timestamp of when the Folder was created.
update_time: Option<Timestamp>Output only. The timestamp of when the Folder was last updated.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
creator_iam_principal: Option<String>Output only. The IAM principal identifier of the creator of the Folder.
Implementations
Sourceimpl Folder
impl Folder
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_containing_folder<T: Into<String>>(self, v: T) -> Self
pub fn set_containing_folder<T: Into<String>>(self, v: T) -> Self
Sets the value of containing_folder.
Example
let x = Folder::new().set_containing_folder("example");Sourcepub fn set_team_folder_name<T: Into<String>>(self, v: T) -> Self
pub fn set_team_folder_name<T: Into<String>>(self, v: T) -> Self
Sets the value of team_folder_name.
Example
let x = Folder::new().set_team_folder_name("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Folder::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Folder::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Folder::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Folder::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Folder::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Folder::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = Folder::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = Folder::new().set_or_clear_internal_metadata(Some("example"));
let x = Folder::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_creator_iam_principal<T>(self, v: T) -> Self
pub fn set_creator_iam_principal<T>(self, v: T) -> Self
Sets the value of creator_iam_principal.
Example
let x = Folder::new().set_creator_iam_principal("example");Sourcepub fn set_or_clear_creator_iam_principal<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creator_iam_principal<T>(self, v: Option<T>) -> Self
Sets or clears the value of creator_iam_principal.
Example
let x = Folder::new().set_or_clear_creator_iam_principal(Some("example"));
let x = Folder::new().set_or_clear_creator_iam_principal(None::<String>);