#[non_exhaustive]pub struct ListWorkspacesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub order_by: String,
pub filter: String,
/* private fields */
}Expand description
ListWorkspaces request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The repository in which to list workspaces. Must be in the
format projects/*/locations/*/repositories/*.
page_size: i32Optional. Maximum number of workspaces to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Page token received from a previous ListWorkspaces call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListWorkspaces, with
the exception of page_size, must match the call that provided the page
token.
order_by: StringOptional. This field only supports ordering by name. If unspecified, the
server will choose the ordering. If specified, the default order is
ascending for the name field.
filter: StringOptional. Filter for the returned list.
Implementations
Sourceimpl ListWorkspacesRequest
impl ListWorkspacesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListWorkspacesRequest::new().set_page_token("example");Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self