#[non_exhaustive]pub struct NotebookRuntimeOptions {
pub ai_platform_notebook_runtime_template: String,
pub execution_sink: Option<ExecutionSink>,
/* private fields */
}Expand description
Configures various aspects of Dataform notebook runtime.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ai_platform_notebook_runtime_template: StringOptional. The resource name of the [Colab runtime template] (https://cloud.google.com/colab/docs/runtimes), from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab’s default specifications.
execution_sink: Option<ExecutionSink>The location to store the notebook execution result.
Implementations
Sourceimpl NotebookRuntimeOptions
impl NotebookRuntimeOptions
Sourcepub fn set_ai_platform_notebook_runtime_template<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_ai_platform_notebook_runtime_template<T: Into<String>>( self, v: T, ) -> Self
Sets the value of ai_platform_notebook_runtime_template.
Example
let x = NotebookRuntimeOptions::new().set_ai_platform_notebook_runtime_template("example");Sourcepub fn set_execution_sink<T: Into<Option<ExecutionSink>>>(self, v: T) -> Self
pub fn set_execution_sink<T: Into<Option<ExecutionSink>>>(self, v: T) -> Self
Sets the value of execution_sink.
Note that all the setters affecting execution_sink are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::notebook_runtime_options::ExecutionSink;
let x = NotebookRuntimeOptions::new().set_execution_sink(Some(ExecutionSink::GcsOutputBucket("example".to_string())));Sourcepub fn gcs_output_bucket(&self) -> Option<&String>
pub fn gcs_output_bucket(&self) -> Option<&String>
The value of execution_sink
if it holds a GcsOutputBucket, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_output_bucket<T: Into<String>>(self, v: T) -> Self
pub fn set_gcs_output_bucket<T: Into<String>>(self, v: T) -> Self
Sets the value of execution_sink
to hold a GcsOutputBucket.
Note that all the setters affecting execution_sink are
mutually exclusive.
Example
let x = NotebookRuntimeOptions::new().set_gcs_output_bucket("example");
assert!(x.gcs_output_bucket().is_some());Trait Implementations
Sourceimpl Clone for NotebookRuntimeOptions
impl Clone for NotebookRuntimeOptions
Sourcefn clone(&self) -> NotebookRuntimeOptions
fn clone(&self) -> NotebookRuntimeOptions
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NotebookRuntimeOptions
impl Debug for NotebookRuntimeOptions
Sourceimpl Default for NotebookRuntimeOptions
impl Default for NotebookRuntimeOptions
Sourcefn default() -> NotebookRuntimeOptions
fn default() -> NotebookRuntimeOptions
Sourceimpl Message for NotebookRuntimeOptions
impl Message for NotebookRuntimeOptions
Sourceimpl PartialEq for NotebookRuntimeOptions
impl PartialEq for NotebookRuntimeOptions
impl StructuralPartialEq for NotebookRuntimeOptions