#[non_exhaustive]pub struct PipelineConfig {
pub pipeline_type: PipelineType,
pub path: String,
/* private fields */
}Expand description
Defines the pipeline type and path within the Git repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pipeline_type: PipelineTypeRequired. The type of the pipeline.
path: StringRequired. The relative path within the Git repository where the pipeline is
defined. For example, for a Dataform pipeline, it is a path to the folder
where workflow_settings.yaml or dataform.json is located.
Implementations
Sourceimpl PipelineConfig
impl PipelineConfig
Sourcepub fn set_pipeline_type<T: Into<PipelineType>>(self, v: T) -> Self
pub fn set_pipeline_type<T: Into<PipelineType>>(self, v: T) -> Self
Sets the value of pipeline_type.
Example
ⓘ
use google_cloud_dataform_v1::model::pipeline_config::PipelineType;
let x0 = PipelineConfig::new().set_pipeline_type(PipelineType::Dataform);
let x1 = PipelineConfig::new().set_pipeline_type(PipelineType::Sql);
let x2 = PipelineConfig::new().set_pipeline_type(PipelineType::Notebook);Trait Implementations
Sourceimpl Clone for PipelineConfig
impl Clone for PipelineConfig
Sourcefn clone(&self) -> PipelineConfig
fn clone(&self) -> PipelineConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PipelineConfig
impl Debug for PipelineConfig
Sourceimpl Default for PipelineConfig
impl Default for PipelineConfig
Sourcefn default() -> PipelineConfig
fn default() -> PipelineConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for PipelineConfig
impl Message for PipelineConfig
Sourceimpl PartialEq for PipelineConfig
impl PartialEq for PipelineConfig
impl StructuralPartialEq for PipelineConfig