#[non_exhaustive]pub struct QueryRepositoryDirectoryContentsRequest {
pub name: String,
pub commit_sha: String,
pub path: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
QueryRepositoryDirectoryContents request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The repository’s name.
commit_sha: StringOptional. The Commit SHA for the commit to query from. If unset, the directory will be queried from HEAD.
path: StringOptional. The directory’s full path including directory name, relative to root. If left unset, the root is used.
page_size: i32Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Page token received from a previous
QueryRepositoryDirectoryContents call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
QueryRepositoryDirectoryContents, with the exception of page_size, must
match the call that provided the page token.
Implementations
Sourceimpl QueryRepositoryDirectoryContentsRequest
impl QueryRepositoryDirectoryContentsRequest
Sourcepub fn set_commit_sha<T: Into<String>>(self, v: T) -> Self
pub fn set_commit_sha<T: Into<String>>(self, v: T) -> Self
Sets the value of commit_sha.
Example
let x = QueryRepositoryDirectoryContentsRequest::new().set_commit_sha("example");Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = QueryRepositoryDirectoryContentsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for QueryRepositoryDirectoryContentsRequest
impl Clone for QueryRepositoryDirectoryContentsRequest
Sourcefn clone(&self) -> QueryRepositoryDirectoryContentsRequest
fn clone(&self) -> QueryRepositoryDirectoryContentsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for QueryRepositoryDirectoryContentsRequest
impl Default for QueryRepositoryDirectoryContentsRequest
Sourcefn default() -> QueryRepositoryDirectoryContentsRequest
fn default() -> QueryRepositoryDirectoryContentsRequest
impl StructuralPartialEq for QueryRepositoryDirectoryContentsRequest