#[non_exhaustive]pub struct QueryTeamFolderContentsResponse {
pub entries: Vec<TeamFolderContentsEntry>,
pub next_page_token: String,
/* private fields */
}Expand description
QueryTeamFolderContents response message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entries: Vec<TeamFolderContentsEntry>List of entries in the TeamFolder.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl QueryTeamFolderContentsResponse
impl QueryTeamFolderContentsResponse
pub fn new() -> Self
Sourcepub fn set_entries<T, V>(self, v: T) -> Self
pub fn set_entries<T, V>(self, v: T) -> Self
Sets the value of entries.
Example
ⓘ
use google_cloud_dataform_v1::model::query_team_folder_contents_response::TeamFolderContentsEntry;
let x = QueryTeamFolderContentsResponse::new()
.set_entries([
TeamFolderContentsEntry::default()/* use setters */,
TeamFolderContentsEntry::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = QueryTeamFolderContentsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for QueryTeamFolderContentsResponse
impl Clone for QueryTeamFolderContentsResponse
Sourcefn clone(&self) -> QueryTeamFolderContentsResponse
fn clone(&self) -> QueryTeamFolderContentsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for QueryTeamFolderContentsResponse
impl Default for QueryTeamFolderContentsResponse
Sourcefn default() -> QueryTeamFolderContentsResponse
fn default() -> QueryTeamFolderContentsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for QueryTeamFolderContentsResponse
impl PartialEq for QueryTeamFolderContentsResponse
Sourcefn eq(&self, other: &QueryTeamFolderContentsResponse) -> bool
fn eq(&self, other: &QueryTeamFolderContentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryTeamFolderContentsResponse