#[non_exhaustive]pub struct QueryUserRootContentsResponse {
pub entries: Vec<RootContentsEntry>,
pub next_page_token: String,
/* private fields */
}Expand description
QueryUserRootContents response message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entries: Vec<RootContentsEntry>List of entries in the folder.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl QueryUserRootContentsResponse
impl QueryUserRootContentsResponse
Sourcepub fn set_entries<T, V>(self, v: T) -> Self
pub fn set_entries<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = QueryUserRootContentsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for QueryUserRootContentsResponse
impl Clone for QueryUserRootContentsResponse
Sourcefn clone(&self) -> QueryUserRootContentsResponse
fn clone(&self) -> QueryUserRootContentsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for QueryUserRootContentsResponse
impl Default for QueryUserRootContentsResponse
Sourcefn default() -> QueryUserRootContentsResponse
fn default() -> QueryUserRootContentsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for QueryUserRootContentsResponse
impl PartialEq for QueryUserRootContentsResponse
Sourcefn eq(&self, other: &QueryUserRootContentsResponse) -> bool
fn eq(&self, other: &QueryUserRootContentsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryUserRootContentsResponse