#[non_exhaustive]pub struct ResetWorkspaceChangesRequest {
pub name: String,
pub paths: Vec<String>,
pub clean: bool,
/* private fields */
}Expand description
ResetWorkspaceChanges request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The workspace’s name.
paths: Vec<String>Optional. Full file paths to reset back to their committed state including filename, rooted at workspace root. If left empty, all files will be reset.
clean: boolOptional. If set to true, untracked files will be deleted.
Implementations