#[non_exhaustive]pub struct TeamFolder {
pub name: String,
pub display_name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub internal_metadata: Option<String>,
pub creator_iam_principal: Option<String>,
/* private fields */
}Expand description
Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The TeamFolder’s name.
display_name: StringRequired. The TeamFolder’s user-friendly name.
create_time: Option<Timestamp>Output only. The timestamp of when the TeamFolder was created.
update_time: Option<Timestamp>Output only. The timestamp of when the TeamFolder was last updated.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
creator_iam_principal: Option<String>Output only. The IAM principal identifier of the creator of the TeamFolder.
Implementations
Sourceimpl TeamFolder
impl TeamFolder
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = TeamFolder::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = TeamFolder::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = TeamFolder::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = TeamFolder::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = TeamFolder::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = TeamFolder::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = TeamFolder::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = TeamFolder::new().set_or_clear_internal_metadata(Some("example"));
let x = TeamFolder::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_creator_iam_principal<T>(self, v: T) -> Self
pub fn set_creator_iam_principal<T>(self, v: T) -> Self
Sets the value of creator_iam_principal.
Example
let x = TeamFolder::new().set_creator_iam_principal("example");Sourcepub fn set_or_clear_creator_iam_principal<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_creator_iam_principal<T>(self, v: Option<T>) -> Self
Sets or clears the value of creator_iam_principal.
Example
let x = TeamFolder::new().set_or_clear_creator_iam_principal(Some("example"));
let x = TeamFolder::new().set_or_clear_creator_iam_principal(None::<String>);Trait Implementations
Sourceimpl Clone for TeamFolder
impl Clone for TeamFolder
Sourcefn clone(&self) -> TeamFolder
fn clone(&self) -> TeamFolder
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TeamFolder
impl Debug for TeamFolder
Sourceimpl Default for TeamFolder
impl Default for TeamFolder
Sourcefn default() -> TeamFolder
fn default() -> TeamFolder
Sourceimpl PartialEq for TeamFolder
impl PartialEq for TeamFolder
impl StructuralPartialEq for TeamFolder