#[non_exhaustive]pub struct UpdateFolderRequest {
pub update_mask: Option<FieldMask>,
pub folder: Option<Folder>,
/* private fields */
}Expand description
UpdateFolder request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Optional. Specifies the fields to be updated in the Folder. If left unset, all fields that can be updated, will be updated. A few fields cannot be updated and will be ignored if specified in the update_mask (e.g. parent_name, team_folder_name).
folder: Option<Folder>Required. The updated Folder.
Implementations
Sourceimpl UpdateFolderRequest
impl UpdateFolderRequest
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateFolderRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateFolderRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateFolderRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_folder<T>(self, v: T) -> Self
pub fn set_folder<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_folder<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_folder<T>(self, v: Option<T>) -> Self