#[non_exhaustive]pub struct WorkflowConfig {
pub name: String,
pub release_config: String,
pub invocation_config: Option<InvocationConfig>,
pub cron_schedule: String,
pub time_zone: String,
pub recent_scheduled_execution_records: Vec<ScheduledExecutionRecord>,
pub disabled: bool,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub internal_metadata: Option<String>,
/* private fields */
}Expand description
Represents a Dataform workflow configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The workflow config’s name.
release_config: StringRequired. The name of the release config whose release_compilation_result
should be executed. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
invocation_config: Option<InvocationConfig>Optional. If left unset, a default InvocationConfig will be used.
cron_schedule: StringOptional. Optional schedule (in cron format) for automatic execution of this workflow config.
time_zone: StringOptional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
recent_scheduled_execution_records: Vec<ScheduledExecutionRecord>Output only. Records of the 10 most recent scheduled execution attempts,
ordered in descending order of execution_time. Updated whenever automatic
creation of a workflow invocation is triggered by cron_schedule.
disabled: boolOptional. Disables automatic creation of workflow invocations.
create_time: Option<Timestamp>Output only. The timestamp of when the WorkflowConfig was created.
update_time: Option<Timestamp>Output only. The timestamp of when the WorkflowConfig was last updated.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
Implementations
Sourceimpl WorkflowConfig
impl WorkflowConfig
Sourcepub fn set_release_config<T: Into<String>>(self, v: T) -> Self
pub fn set_release_config<T: Into<String>>(self, v: T) -> Self
Sets the value of release_config.
Example
let x = WorkflowConfig::new().set_release_config(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/releaseConfigs/{release_config_id}"));Sourcepub fn set_invocation_config<T>(self, v: T) -> Selfwhere
T: Into<InvocationConfig>,
pub fn set_invocation_config<T>(self, v: T) -> Selfwhere
T: Into<InvocationConfig>,
Sets the value of invocation_config.
Example
use google_cloud_dataform_v1::model::InvocationConfig;
let x = WorkflowConfig::new().set_invocation_config(InvocationConfig::default()/* use setters */);Sourcepub fn set_or_clear_invocation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InvocationConfig>,
pub fn set_or_clear_invocation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InvocationConfig>,
Sets or clears the value of invocation_config.
Example
use google_cloud_dataform_v1::model::InvocationConfig;
let x = WorkflowConfig::new().set_or_clear_invocation_config(Some(InvocationConfig::default()/* use setters */));
let x = WorkflowConfig::new().set_or_clear_invocation_config(None::<InvocationConfig>);Sourcepub fn set_cron_schedule<T: Into<String>>(self, v: T) -> Self
pub fn set_cron_schedule<T: Into<String>>(self, v: T) -> Self
Sets the value of cron_schedule.
Example
let x = WorkflowConfig::new().set_cron_schedule("example");Sourcepub fn set_time_zone<T: Into<String>>(self, v: T) -> Self
pub fn set_time_zone<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_recent_scheduled_execution_records<T, V>(self, v: T) -> Self
pub fn set_recent_scheduled_execution_records<T, V>(self, v: T) -> Self
Sets the value of recent_scheduled_execution_records.
Example
use google_cloud_dataform_v1::model::workflow_config::ScheduledExecutionRecord;
let x = WorkflowConfig::new()
.set_recent_scheduled_execution_records([
ScheduledExecutionRecord::default()/* use setters */,
ScheduledExecutionRecord::default()/* use (different) setters */,
]);Sourcepub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_disabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = WorkflowConfig::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = WorkflowConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = WorkflowConfig::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = WorkflowConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = WorkflowConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = WorkflowConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = WorkflowConfig::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = WorkflowConfig::new().set_or_clear_internal_metadata(Some("example"));
let x = WorkflowConfig::new().set_or_clear_internal_metadata(None::<String>);Trait Implementations
Sourceimpl Clone for WorkflowConfig
impl Clone for WorkflowConfig
Sourcefn clone(&self) -> WorkflowConfig
fn clone(&self) -> WorkflowConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowConfig
impl Debug for WorkflowConfig
Sourceimpl Default for WorkflowConfig
impl Default for WorkflowConfig
Sourcefn default() -> WorkflowConfig
fn default() -> WorkflowConfig
Sourceimpl Message for WorkflowConfig
impl Message for WorkflowConfig
Sourceimpl PartialEq for WorkflowConfig
impl PartialEq for WorkflowConfig
impl StructuralPartialEq for WorkflowConfig