#[non_exhaustive]pub struct WorkflowInvocation {
pub name: String,
pub invocation_config: Option<InvocationConfig>,
pub state: State,
pub invocation_timing: Option<Interval>,
pub resolved_compilation_result: String,
pub data_encryption_state: Option<DataEncryptionState>,
pub internal_metadata: Option<String>,
pub private_resource_metadata: Option<PrivateResourceMetadata>,
pub compilation_source: Option<CompilationSource>,
/* private fields */
}Expand description
Represents a single invocation of a compilation result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The workflow invocation’s name.
invocation_config: Option<InvocationConfig>Immutable. If left unset, a default InvocationConfig will be used.
state: StateOutput only. This workflow invocation’s current state.
invocation_timing: Option<Interval>Output only. This workflow invocation’s timing details.
resolved_compilation_result: StringOutput only. The resolved compilation result that was used to create this
invocation. Will be in the format
projects/*/locations/*/repositories/*/compilationResults/*.
data_encryption_state: Option<DataEncryptionState>Output only. Only set if the repository has a KMS Key.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
private_resource_metadata: Option<PrivateResourceMetadata>Output only. Metadata indicating whether this resource is user-scoped.
WorkflowInvocation resource is user_scoped only if it is sourced
from a compilation result and the compilation result is user-scoped.
compilation_source: Option<CompilationSource>The source of the compilation result to use for this invocation.
Implementations
Sourceimpl WorkflowInvocation
impl WorkflowInvocation
Sourcepub fn set_invocation_config<T>(self, v: T) -> Selfwhere
T: Into<InvocationConfig>,
pub fn set_invocation_config<T>(self, v: T) -> Selfwhere
T: Into<InvocationConfig>,
Sets the value of invocation_config.
Example
use google_cloud_dataform_v1::model::InvocationConfig;
let x = WorkflowInvocation::new().set_invocation_config(InvocationConfig::default()/* use setters */);Sourcepub fn set_or_clear_invocation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InvocationConfig>,
pub fn set_or_clear_invocation_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InvocationConfig>,
Sets or clears the value of invocation_config.
Example
use google_cloud_dataform_v1::model::InvocationConfig;
let x = WorkflowInvocation::new().set_or_clear_invocation_config(Some(InvocationConfig::default()/* use setters */));
let x = WorkflowInvocation::new().set_or_clear_invocation_config(None::<InvocationConfig>);Sourcepub fn set_invocation_timing<T>(self, v: T) -> Self
pub fn set_invocation_timing<T>(self, v: T) -> Self
Sets the value of invocation_timing.
Example
use google_cloud_type::model::Interval;
let x = WorkflowInvocation::new().set_invocation_timing(Interval::default()/* use setters */);Sourcepub fn set_or_clear_invocation_timing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_invocation_timing<T>(self, v: Option<T>) -> Self
Sets or clears the value of invocation_timing.
Example
use google_cloud_type::model::Interval;
let x = WorkflowInvocation::new().set_or_clear_invocation_timing(Some(Interval::default()/* use setters */));
let x = WorkflowInvocation::new().set_or_clear_invocation_timing(None::<Interval>);Sourcepub fn set_resolved_compilation_result<T: Into<String>>(self, v: T) -> Self
pub fn set_resolved_compilation_result<T: Into<String>>(self, v: T) -> Self
Sets the value of resolved_compilation_result.
Example
let x = WorkflowInvocation::new().set_resolved_compilation_result(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/compilationResults/{compilation_result_id}"));Sourcepub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
Sets the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = WorkflowInvocation::new().set_data_encryption_state(DataEncryptionState::default()/* use setters */);Sourcepub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
Sets or clears the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = WorkflowInvocation::new().set_or_clear_data_encryption_state(Some(DataEncryptionState::default()/* use setters */));
let x = WorkflowInvocation::new().set_or_clear_data_encryption_state(None::<DataEncryptionState>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = WorkflowInvocation::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = WorkflowInvocation::new().set_or_clear_internal_metadata(Some("example"));
let x = WorkflowInvocation::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = WorkflowInvocation::new().set_private_resource_metadata(PrivateResourceMetadata::default()/* use setters */);Sourcepub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets or clears the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = WorkflowInvocation::new().set_or_clear_private_resource_metadata(Some(PrivateResourceMetadata::default()/* use setters */));
let x = WorkflowInvocation::new().set_or_clear_private_resource_metadata(None::<PrivateResourceMetadata>);Sourcepub fn set_compilation_source<T: Into<Option<CompilationSource>>>(
self,
v: T,
) -> Self
pub fn set_compilation_source<T: Into<Option<CompilationSource>>>( self, v: T, ) -> Self
Sets the value of compilation_source.
Note that all the setters affecting compilation_source are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation::CompilationSource;
let x = WorkflowInvocation::new().set_compilation_source(Some(CompilationSource::CompilationResult("example".to_string())));Sourcepub fn compilation_result(&self) -> Option<&String>
pub fn compilation_result(&self) -> Option<&String>
The value of compilation_source
if it holds a CompilationResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_compilation_result<T: Into<String>>(self, v: T) -> Self
pub fn set_compilation_result<T: Into<String>>(self, v: T) -> Self
Sets the value of compilation_source
to hold a CompilationResult.
Note that all the setters affecting compilation_source are
mutually exclusive.
Example
let x = WorkflowInvocation::new().set_compilation_result(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/compilationResults/{compilation_result_id}"));
assert!(x.compilation_result().is_some());
assert!(x.workflow_config().is_none());Sourcepub fn workflow_config(&self) -> Option<&String>
pub fn workflow_config(&self) -> Option<&String>
The value of compilation_source
if it holds a WorkflowConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_workflow_config<T: Into<String>>(self, v: T) -> Self
pub fn set_workflow_config<T: Into<String>>(self, v: T) -> Self
Sets the value of compilation_source
to hold a WorkflowConfig.
Note that all the setters affecting compilation_source are
mutually exclusive.
Example
let x = WorkflowInvocation::new().set_workflow_config(format!("projects/{project_id}/locations/{location_id}/repositories/{repository_id}/workflowConfigs/{workflow_config_id}"));
assert!(x.workflow_config().is_some());
assert!(x.compilation_result().is_none());Trait Implementations
Sourceimpl Clone for WorkflowInvocation
impl Clone for WorkflowInvocation
Sourcefn clone(&self) -> WorkflowInvocation
fn clone(&self) -> WorkflowInvocation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowInvocation
impl Debug for WorkflowInvocation
Sourceimpl Default for WorkflowInvocation
impl Default for WorkflowInvocation
Sourcefn default() -> WorkflowInvocation
fn default() -> WorkflowInvocation
Sourceimpl Message for WorkflowInvocation
impl Message for WorkflowInvocation
Sourceimpl PartialEq for WorkflowInvocation
impl PartialEq for WorkflowInvocation
impl StructuralPartialEq for WorkflowInvocation