#[non_exhaustive]pub struct WorkflowInvocationAction {
pub target: Option<Target>,
pub canonical_target: Option<Target>,
pub state: State,
pub failure_reason: String,
pub invocation_timing: Option<Interval>,
pub internal_metadata: Option<String>,
pub action: Option<Action>,
/* private fields */
}Expand description
Represents a single action in a workflow invocation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target: Option<Target>Output only. This action’s identifier. Unique within the workflow invocation.
canonical_target: Option<Target>Output only. The action’s identifier if the project had been compiled without any overrides configured. Unique within the compilation result.
state: StateOutput only. This action’s current state.
failure_reason: StringOutput only. If and only if action’s state is FAILED a failure reason is set.
invocation_timing: Option<Interval>Output only. This action’s timing details.
start_time will be set if the action is in [RUNNING, SUCCEEDED,
CANCELLED, FAILED] state.
end_time will be set if the action is in [SUCCEEDED, CANCELLED, FAILED]
state.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
action: Option<Action>The action’s details.
Implementations
Sourceimpl WorkflowInvocationAction
impl WorkflowInvocationAction
Sourcepub fn set_target<T>(self, v: T) -> Self
pub fn set_target<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_target<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_target<T>(self, v: Option<T>) -> Self
Sourcepub fn set_canonical_target<T>(self, v: T) -> Self
pub fn set_canonical_target<T>(self, v: T) -> Self
Sets the value of canonical_target.
Example
use google_cloud_dataform_v1::model::Target;
let x = WorkflowInvocationAction::new().set_canonical_target(Target::default()/* use setters */);Sourcepub fn set_or_clear_canonical_target<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_canonical_target<T>(self, v: Option<T>) -> Self
Sets or clears the value of canonical_target.
Example
use google_cloud_dataform_v1::model::Target;
let x = WorkflowInvocationAction::new().set_or_clear_canonical_target(Some(Target::default()/* use setters */));
let x = WorkflowInvocationAction::new().set_or_clear_canonical_target(None::<Target>);Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::State;
let x0 = WorkflowInvocationAction::new().set_state(State::Running);
let x1 = WorkflowInvocationAction::new().set_state(State::Skipped);
let x2 = WorkflowInvocationAction::new().set_state(State::Disabled);Sourcepub fn set_failure_reason<T: Into<String>>(self, v: T) -> Self
pub fn set_failure_reason<T: Into<String>>(self, v: T) -> Self
Sets the value of failure_reason.
Example
let x = WorkflowInvocationAction::new().set_failure_reason("example");Sourcepub fn set_invocation_timing<T>(self, v: T) -> Self
pub fn set_invocation_timing<T>(self, v: T) -> Self
Sets the value of invocation_timing.
Example
use google_cloud_type::model::Interval;
let x = WorkflowInvocationAction::new().set_invocation_timing(Interval::default()/* use setters */);Sourcepub fn set_or_clear_invocation_timing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_invocation_timing<T>(self, v: Option<T>) -> Self
Sets or clears the value of invocation_timing.
Example
use google_cloud_type::model::Interval;
let x = WorkflowInvocationAction::new().set_or_clear_invocation_timing(Some(Interval::default()/* use setters */));
let x = WorkflowInvocationAction::new().set_or_clear_invocation_timing(None::<Interval>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = WorkflowInvocationAction::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = WorkflowInvocationAction::new().set_or_clear_internal_metadata(Some("example"));
let x = WorkflowInvocationAction::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
pub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
Sets the value of action.
Note that all the setters affecting action are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::BigQueryAction;
let x = WorkflowInvocationAction::new().set_action(Some(
google_cloud_dataform_v1::model::workflow_invocation_action::Action::BigqueryAction(BigQueryAction::default().into())));Sourcepub fn bigquery_action(&self) -> Option<&Box<BigQueryAction>>
pub fn bigquery_action(&self) -> Option<&Box<BigQueryAction>>
The value of action
if it holds a BigqueryAction, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_action<T: Into<Box<BigQueryAction>>>(self, v: T) -> Self
pub fn set_bigquery_action<T: Into<Box<BigQueryAction>>>(self, v: T) -> Self
Sets the value of action
to hold a BigqueryAction.
Note that all the setters affecting action are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::BigQueryAction;
let x = WorkflowInvocationAction::new().set_bigquery_action(BigQueryAction::default()/* use setters */);
assert!(x.bigquery_action().is_some());
assert!(x.notebook_action().is_none());
assert!(x.data_preparation_action().is_none());Sourcepub fn notebook_action(&self) -> Option<&Box<NotebookAction>>
pub fn notebook_action(&self) -> Option<&Box<NotebookAction>>
The value of action
if it holds a NotebookAction, None if the field is not set or
holds a different branch.
Sourcepub fn set_notebook_action<T: Into<Box<NotebookAction>>>(self, v: T) -> Self
pub fn set_notebook_action<T: Into<Box<NotebookAction>>>(self, v: T) -> Self
Sets the value of action
to hold a NotebookAction.
Note that all the setters affecting action are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::NotebookAction;
let x = WorkflowInvocationAction::new().set_notebook_action(NotebookAction::default()/* use setters */);
assert!(x.notebook_action().is_some());
assert!(x.bigquery_action().is_none());
assert!(x.data_preparation_action().is_none());Sourcepub fn data_preparation_action(&self) -> Option<&Box<DataPreparationAction>>
pub fn data_preparation_action(&self) -> Option<&Box<DataPreparationAction>>
The value of action
if it holds a DataPreparationAction, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_preparation_action<T: Into<Box<DataPreparationAction>>>(
self,
v: T,
) -> Self
pub fn set_data_preparation_action<T: Into<Box<DataPreparationAction>>>( self, v: T, ) -> Self
Sets the value of action
to hold a DataPreparationAction.
Note that all the setters affecting action are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::DataPreparationAction;
let x = WorkflowInvocationAction::new().set_data_preparation_action(DataPreparationAction::default()/* use setters */);
assert!(x.data_preparation_action().is_some());
assert!(x.bigquery_action().is_none());
assert!(x.notebook_action().is_none());Trait Implementations
Sourceimpl Clone for WorkflowInvocationAction
impl Clone for WorkflowInvocationAction
Sourcefn clone(&self) -> WorkflowInvocationAction
fn clone(&self) -> WorkflowInvocationAction
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowInvocationAction
impl Debug for WorkflowInvocationAction
Sourceimpl Default for WorkflowInvocationAction
impl Default for WorkflowInvocationAction
Sourcefn default() -> WorkflowInvocationAction
fn default() -> WorkflowInvocationAction
Sourceimpl Message for WorkflowInvocationAction
impl Message for WorkflowInvocationAction
Sourceimpl PartialEq for WorkflowInvocationAction
impl PartialEq for WorkflowInvocationAction
impl StructuralPartialEq for WorkflowInvocationAction