#[non_exhaustive]pub struct Workspace {
pub name: String,
pub create_time: Option<Timestamp>,
pub data_encryption_state: Option<DataEncryptionState>,
pub internal_metadata: Option<String>,
pub disable_moves: Option<bool>,
pub private_resource_metadata: Option<PrivateResourceMetadata>,
/* private fields */
}Expand description
Represents a Dataform Git workspace.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The workspace’s name.
create_time: Option<Timestamp>Output only. The timestamp of when the workspace was created.
data_encryption_state: Option<DataEncryptionState>Output only. A data encryption state of a Git repository if this Workspace is protected by a KMS key.
internal_metadata: Option<String>Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
disable_moves: Option<bool>Optional. If set to true, workspaces will not be moved if its linked Repository is moved. Instead, it will be deleted.
private_resource_metadata: Option<PrivateResourceMetadata>Output only. Metadata indicating whether this resource is user-scoped. For
Workspace resources, the user_scoped field is always true.
Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Workspace::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Workspace::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Workspace::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_data_encryption_state<T>(self, v: T) -> Selfwhere
T: Into<DataEncryptionState>,
Sets the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = Workspace::new().set_data_encryption_state(DataEncryptionState::default()/* use setters */);Sourcepub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
pub fn set_or_clear_data_encryption_state<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataEncryptionState>,
Sets or clears the value of data_encryption_state.
Example
use google_cloud_dataform_v1::model::DataEncryptionState;
let x = Workspace::new().set_or_clear_data_encryption_state(Some(DataEncryptionState::default()/* use setters */));
let x = Workspace::new().set_or_clear_data_encryption_state(None::<DataEncryptionState>);Sourcepub fn set_internal_metadata<T>(self, v: T) -> Self
pub fn set_internal_metadata<T>(self, v: T) -> Self
Sets the value of internal_metadata.
Example
let x = Workspace::new().set_internal_metadata("example");Sourcepub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_internal_metadata<T>(self, v: Option<T>) -> Self
Sets or clears the value of internal_metadata.
Example
let x = Workspace::new().set_or_clear_internal_metadata(Some("example"));
let x = Workspace::new().set_or_clear_internal_metadata(None::<String>);Sourcepub fn set_disable_moves<T>(self, v: T) -> Self
pub fn set_disable_moves<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_disable_moves<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_disable_moves<T>(self, v: Option<T>) -> Self
Sets or clears the value of disable_moves.
Example
let x = Workspace::new().set_or_clear_disable_moves(Some(false));
let x = Workspace::new().set_or_clear_disable_moves(None::<bool>);Sourcepub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_private_resource_metadata<T>(self, v: T) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = Workspace::new().set_private_resource_metadata(PrivateResourceMetadata::default()/* use setters */);Sourcepub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
pub fn set_or_clear_private_resource_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrivateResourceMetadata>,
Sets or clears the value of private_resource_metadata.
Example
use google_cloud_dataform_v1::model::PrivateResourceMetadata;
let x = Workspace::new().set_or_clear_private_resource_metadata(Some(PrivateResourceMetadata::default()/* use setters */));
let x = Workspace::new().set_or_clear_private_resource_metadata(None::<PrivateResourceMetadata>);Trait Implementations
impl StructuralPartialEq for Workspace