Module workflow_invocation_action

Module workflow_invocation_action 

Defines additional types related to WorkflowInvocationAction.

Modules

data_preparation_action
Defines additional types related to DataPreparationAction.

Structs

BigQueryAction
Represents a workflow action that will run against BigQuery.
DataPreparationAction
Represents a workflow action that will run a Data Preparation.
NotebookAction
Represents a workflow action that will run against a Notebook runtime.

Enums

Action
The action’s details.
State
Represents the current state of a workflow invocation action.