#[non_exhaustive]pub struct DataPreparationAction {
pub generated_sql: String,
pub job_id: String,
pub definition: Option<Definition>,
/* private fields */
}Expand description
Represents a workflow action that will run a Data Preparation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generated_sql: StringOutput only. The generated BigQuery SQL script that will be executed. For reference only.
job_id: StringOutput only. The ID of the BigQuery job that executed the SQL in sql_script. Only set once the job has started to run.
definition: Option<Definition>The definition for the data preparation.
Implementations
Sourceimpl DataPreparationAction
impl DataPreparationAction
Sourcepub fn set_generated_sql<T: Into<String>>(self, v: T) -> Self
pub fn set_generated_sql<T: Into<String>>(self, v: T) -> Self
Sets the value of generated_sql.
Example
let x = DataPreparationAction::new().set_generated_sql("example");Sourcepub fn set_job_id<T: Into<String>>(self, v: T) -> Self
pub fn set_job_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
pub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
Sets the value of definition.
Note that all the setters affecting definition are mutually
exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::data_preparation_action::Definition;
let x = DataPreparationAction::new().set_definition(Some(Definition::ContentsYaml("example".to_string())));Sourcepub fn contents_yaml(&self) -> Option<&String>
pub fn contents_yaml(&self) -> Option<&String>
The value of definition
if it holds a ContentsYaml, None if the field is not set or
holds a different branch.
Sourcepub fn set_contents_yaml<T: Into<String>>(self, v: T) -> Self
pub fn set_contents_yaml<T: Into<String>>(self, v: T) -> Self
Sets the value of definition
to hold a ContentsYaml.
Note that all the setters affecting definition are
mutually exclusive.
Example
let x = DataPreparationAction::new().set_contents_yaml("example");
assert!(x.contents_yaml().is_some());
assert!(x.contents_sql().is_none());Sourcepub fn contents_sql(&self) -> Option<&Box<ActionSqlDefinition>>
pub fn contents_sql(&self) -> Option<&Box<ActionSqlDefinition>>
The value of definition
if it holds a ContentsSql, None if the field is not set or
holds a different branch.
Sourcepub fn set_contents_sql<T: Into<Box<ActionSqlDefinition>>>(self, v: T) -> Self
pub fn set_contents_sql<T: Into<Box<ActionSqlDefinition>>>(self, v: T) -> Self
Sets the value of definition
to hold a ContentsSql.
Note that all the setters affecting definition are
mutually exclusive.
Example
use google_cloud_dataform_v1::model::workflow_invocation_action::data_preparation_action::ActionSqlDefinition;
let x = DataPreparationAction::new().set_contents_sql(ActionSqlDefinition::default()/* use setters */);
assert!(x.contents_sql().is_some());
assert!(x.contents_yaml().is_none());Trait Implementations
Sourceimpl Clone for DataPreparationAction
impl Clone for DataPreparationAction
Sourcefn clone(&self) -> DataPreparationAction
fn clone(&self) -> DataPreparationAction
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataPreparationAction
impl Debug for DataPreparationAction
Sourceimpl Default for DataPreparationAction
impl Default for DataPreparationAction
Sourcefn default() -> DataPreparationAction
fn default() -> DataPreparationAction
Sourceimpl Message for DataPreparationAction
impl Message for DataPreparationAction
Sourceimpl PartialEq for DataPreparationAction
impl PartialEq for DataPreparationAction
impl StructuralPartialEq for DataPreparationAction