#[non_exhaustive]pub enum DirectoryContentsView {
Unspecified,
Basic,
Metadata,
UnknownValue(UnknownValue),
}Expand description
Represents the level of detail to return for directory contents.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default / unset value. Defaults to DIRECTORY_CONTENTS_VIEW_BASIC.
Basic
Includes only the file or directory name. This is the default behavior.
Metadata
Includes all metadata for each file or directory. Currently not supported by CMEK-protected workspaces.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DirectoryContentsView::value or DirectoryContentsView::name.
Implementations