#[non_exhaustive]pub struct InvocationConfig {
pub included_targets: Vec<Target>,
pub included_tags: Vec<String>,
pub transitive_dependencies_included: bool,
pub transitive_dependents_included: bool,
pub fully_refresh_incremental_tables_enabled: bool,
pub service_account: String,
pub query_priority: Option<QueryPriority>,
/* private fields */
}Expand description
Includes various configuration options for a workflow invocation.
If both included_targets and included_tags are unset, all actions
will be included.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.included_targets: Vec<Target>Optional. The set of action identifiers to include.
Optional. The set of tags to include.
transitive_dependencies_included: boolOptional. When set to true, transitive dependencies of included actions will be executed.
transitive_dependents_included: boolOptional. When set to true, transitive dependents of included actions will be executed.
fully_refresh_incremental_tables_enabled: boolOptional. When set to true, any incremental tables will be fully refreshed.
service_account: StringOptional. The service account to run workflow invocations under.
query_priority: Option<QueryPriority>Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#queries.
Implementations
Sourceimpl InvocationConfig
impl InvocationConfig
Sourcepub fn set_included_targets<T, V>(self, v: T) -> Self
pub fn set_included_targets<T, V>(self, v: T) -> Self
Sets the value of included_targets.
Example
use google_cloud_dataform_v1::model::Target;
let x = InvocationConfig::new()
.set_included_targets([
Target::default()/* use setters */,
Target::default()/* use (different) setters */,
]);Sets the value of included_tags.
Example
let x = InvocationConfig::new().set_included_tags(["a", "b", "c"]);Sourcepub fn set_transitive_dependencies_included<T: Into<bool>>(self, v: T) -> Self
pub fn set_transitive_dependencies_included<T: Into<bool>>(self, v: T) -> Self
Sets the value of transitive_dependencies_included.
Example
let x = InvocationConfig::new().set_transitive_dependencies_included(true);Sourcepub fn set_transitive_dependents_included<T: Into<bool>>(self, v: T) -> Self
pub fn set_transitive_dependents_included<T: Into<bool>>(self, v: T) -> Self
Sets the value of transitive_dependents_included.
Example
let x = InvocationConfig::new().set_transitive_dependents_included(true);Sourcepub fn set_fully_refresh_incremental_tables_enabled<T: Into<bool>>(
self,
v: T,
) -> Self
pub fn set_fully_refresh_incremental_tables_enabled<T: Into<bool>>( self, v: T, ) -> Self
Sets the value of fully_refresh_incremental_tables_enabled.
Example
let x = InvocationConfig::new().set_fully_refresh_incremental_tables_enabled(true);Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = InvocationConfig::new().set_service_account("example");Sourcepub fn set_query_priority<T>(self, v: T) -> Selfwhere
T: Into<QueryPriority>,
pub fn set_query_priority<T>(self, v: T) -> Selfwhere
T: Into<QueryPriority>,
Sets the value of query_priority.
Example
use google_cloud_dataform_v1::model::invocation_config::QueryPriority;
let x0 = InvocationConfig::new().set_query_priority(QueryPriority::Interactive);
let x1 = InvocationConfig::new().set_query_priority(QueryPriority::Batch);Sourcepub fn set_or_clear_query_priority<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryPriority>,
pub fn set_or_clear_query_priority<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryPriority>,
Sets or clears the value of query_priority.
Example
use google_cloud_dataform_v1::model::invocation_config::QueryPriority;
let x0 = InvocationConfig::new().set_or_clear_query_priority(Some(QueryPriority::Interactive));
let x1 = InvocationConfig::new().set_or_clear_query_priority(Some(QueryPriority::Batch));
let x_none = InvocationConfig::new().set_or_clear_query_priority(None::<QueryPriority>);Trait Implementations
Sourceimpl Clone for InvocationConfig
impl Clone for InvocationConfig
Sourcefn clone(&self) -> InvocationConfig
fn clone(&self) -> InvocationConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more