#[non_exhaustive]pub struct QueryDirectoryContentsRequest {
pub workspace: String,
pub path: String,
pub page_size: i32,
pub page_token: String,
pub view: DirectoryContentsView,
/* private fields */
}Expand description
QueryDirectoryContents request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workspace: StringRequired. The workspace’s name.
path: StringOptional. The directory’s full path including directory name, relative to the workspace root. If left unset, the workspace root is used.
page_size: i32Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Page token received from a previous QueryDirectoryContents
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryDirectoryContents, with the exception of page_size, must match the
call that provided the page token.
view: DirectoryContentsViewOptional. Specifies the metadata to return for each directory entry.
If unspecified, the default is DIRECTORY_CONTENTS_VIEW_BASIC.
Currently the DIRECTORY_CONTENTS_VIEW_METADATA view is not supported by
CMEK-protected workspaces.
Implementations
Sourceimpl QueryDirectoryContentsRequest
impl QueryDirectoryContentsRequest
pub fn new() -> Self
Sourcepub fn set_workspace<T: Into<String>>(self, v: T) -> Self
pub fn set_workspace<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = QueryDirectoryContentsRequest::new().set_page_token("example");Sourcepub fn set_view<T: Into<DirectoryContentsView>>(self, v: T) -> Self
pub fn set_view<T: Into<DirectoryContentsView>>(self, v: T) -> Self