#[non_exhaustive]pub struct QueryUserRootContentsRequest {
pub location: String,
pub page_size: i32,
pub page_token: String,
pub order_by: String,
pub filter: String,
/* private fields */
}Expand description
QueryUserRootContents request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: StringRequired. Location of the user root folder whose contents to list. Format: projects//locations/
page_size: i32Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Page token received from a previous QueryUserRootContents call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryUserRootFolderContents, with the exception of page_size, must
match the call that provided the page token.
order_by: StringOptional. Field to additionally sort results by.
Will order Folders before Repositories, and then by order_by in ascending
order. Supported keywords: display_name (default), created_at,
last_modified_at. Examples:
orderBy="display_name"orderBy="display_name desc"
filter: StringOptional. Optional filtering for the returned list. Filtering is currently
only supported on the display_name field.
Example:
filter="display_name="MyFolder""
Implementations
Sourceimpl QueryUserRootContentsRequest
impl QueryUserRootContentsRequest
Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = QueryUserRootContentsRequest::new().set_page_token("example");Sourcepub fn set_order_by<T: Into<String>>(self, v: T) -> Self
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self