Defines additional types related to WorkflowInvocationAction.
Modules
- data_
preparation_ action - Defines additional types related to DataPreparationAction.
Structs
- BigQuery
Action - Represents a workflow action that will run against BigQuery.
- Data
Preparation Action - Represents a workflow action that will run a Data Preparation.
- Notebook
Action - Represents a workflow action that will run against a Notebook runtime.